// Copyright 2011 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.api.ads.adwords.lib.factory;

import com.google.api.ads.adwords.lib.AdWordsSoapModule;
import com.google.api.ads.adwords.lib.client.AdWordsSession;
import com.google.api.ads.common.lib.factory.FactoryConfiguration;
import com.google.api.ads.common.lib.soap.ProductFrameworkModule;
import com.google.common.annotations.VisibleForTesting;

import javax.annotation.Nullable;

/**
 * Utility class to create AdWords service clients. The session is stored
 * as a reference within the client so that the session may be altered to
 * affect the behavior of the client.
 * <p>
 * Usage example:
 * <pre><code>
 * AdWordsSession session = new AdWordsSession.Builder()...build();
 * CampaignServiceInterface campaignService =
 *    new AdWordsServices().get(session, CampaignServiceInterface.class);
 * campaignService.get(...);
 * ...
 * session.setClientCustomerId(...);
 * campaignService.get(...);
 * </code></pre>
 *
 * @author Adam Rogal
 * @deprecated use {@link com.google.api.ads.adwords.axis.factory.AdWordsServices}
 *             or {@link com.google.api.ads.adwords.jaxws.factory.AdWordsServices}
 *             instead.
 */
@Deprecated
public final class AdWordsServices {

  private final AdWordsServiceClientFactory factory;

  /**
   * Default constructor.
   */
  public AdWordsServices() {
    this(new FactoryConfiguration.Builder().buildDefault());
  }

  /**
   * Constructor that takes a factory.
   * @param factory the factory to create services from.
   */
  @VisibleForTesting
  AdWordsServices(AdWordsServiceClientFactory factory) {
    this.factory = factory;
  }

  /**
   * Constructor that takes a factory configuration.
   * @param factoryConfiguration the factory configuration
   */
  public AdWordsServices(@Nullable FactoryConfiguration factoryConfiguration) {
    if (factoryConfiguration == null || factoryConfiguration.getAdWordsSoapModule() == null) {
      factory = new AdWordsServiceClientFactory(
          ProductFrameworkModule.determineSoapModule(AdWordsSoapModule.class));
    } else {
      factory = new AdWordsServiceClientFactory(factoryConfiguration.getAdWordsSoapModule());
    }
  }

  /**
   * Gets a client for the service represented by the interface with a reference
   * to the session.
   *
   * @param <T> the service type
   * @param adWordsSession the AdWords session
   * @param interfaceClass the service interface class
   * @return the client for the service
   */
  public <T> T get(AdWordsSession adWordsSession, Class<T> interfaceClass) {
    return factory.getServiceClientAsInterface(adWordsSession, interfaceClass);
  }
}
